Name:           libproxy
Version:        0.4.15
Release:        18
Summary:        Libproxy is a library that provides automatic proxy configuration management

License:        LGPLv2+
URL:            https://libproxy.github.io/libproxy/
Source0:        https://github.com/libproxy/%{name}/archive/%{version}.tar.gz
# Source1 comes from the Debian package.
Source1:        proxy.1
# Patch from google code
Patch0:         0001-Add-config-module-for-querying-PacRunner-d-mon.patch
Patch1:         libproxy-0.4.11-crash.patch
# Patch 2 and 3 are backported from upstream commuity
Patch2:         libproxy-0.4.15-python3738.patch
Patch3:         Fix-buffer-overflow-when-PAC-is-enabled.patch 
Patch4:		backport-Fix-mismatched-new-delete-in-proxy.cpp.patch
Patch5:		CVE-2020-25219-Rewrite-url-recvline-to-be-nonrecursive.patch

BuildRequires:  cmake >= 2.6.0 gcc-c++
BuildRequires:  pkgconfig(gio-2.0) >= 2.26 pkgconfig(libnm) python2-devel python3-devel
BuildRequires:  pkgconfig(dbus-1) pkgconfig(javascriptcoregtk-4.0) 

Provides:       %{name}-bin %{name}-gnome %{name}-kde %{name}-networkmanager %{name}-pacrunner 
Obsoletes:      %{name}-bin %{name}-gnome %{name}-kde %{name}-mozjs %{name}-networkmanager %{name}-pacrunner 

%description
libproxy offers the following features:
    * extremely small core footprint (< 35K).
    * no external dependencies within libproxy core.
      (libproxy plugins may have dependencies).
    * only 3 functions in the stable external API.
    * dynamic adjustment to changing network topology.
    * a standard way of dealing with proxy settings across all scenarios.

%package -n     python2-%{name}
Summary:        Binding for %{name} and python2
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
%{?python_provide:%python_provide python2-%{name}}

%description -n python2-%{name}
The python2 binding for libproxy.

%package -n     python3-%{name}
Summary:        Binding for %{name} and python3
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
The python3 binding for libproxy.

%package        webkitgtk4
Summary:        plugin for webkit2gtk3
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-pac = %{version}-%{release}

%description    webkitgtk4
plugin for webkit2gtk3.

%package        devel
Summary:        Libproxy provides consistent proxy configuration to applications - Development Files
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
This package contains libraries and header files for developing applications.

%package_help

%prep
%autosetup -p1

%build
%{cmake} \
  -DMODULE_INSTALL_DIR=%{_libdir}/%{name}/%{version}/modules \
  -DBIPR=OFF \
  -DWITH_PERL=OFF -DWITH_GNOME3=ON -DWITH_PYTHON2=ON -DPYTHON2_EXECUTABLE=%{__python2} \
  -DWITH_PYTHON3=ON -DWITH_WEBKIT3=ON -DWITH_MOZJS=OFF .
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_libdir}/%{name}/%{version}/modules
install -Dpm 0644 %{SOURCE1} %{buildroot}/%{_mandir}/man1/proxy.1

%check
make test

%ldconfig_scriptlets

%files
%defattr(-,root,root)
%doc AUTHORS README 
%license COPYING
%{_libdir}/*.so.*
%{_bindir}/proxy
%{_libdir}/%{name}/%{version}/modules/*
%{_libexecdir}/pxgsettings
%exclude %{_libdir}/%{name}/%{version}/modules/pacrunner_webkit.so

%files -n python2-%{name}
%defattr(-,root,root)
%{python2_sitelib}/%{name}.*

%files -n python3-%{name}
%defattr(-,root,root)
%{python3_sitelib}/__pycache__/*
%{python3_sitelib}/%{name}.*

%files webkitgtk4
%defattr(-,root,root)
%{_libdir}/%{name}/%{version}/modules/pacrunner_webkit.so

%files devel
%defattr(-,root,root)
%{_includedir}/proxy.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/libproxy-1.0.pc
%{_datadir}/cmake/Modules/Findlibproxy.cmake

%files help
%defattr(-,root,root)
%{_mandir}/man1/proxy.1*

%changelog
* Thu Jul 14 2022 zhouyihang <zhouyihang3@h-partners.com> - 0.4.15-18
- Type:cves
- CVE:CVE-2020-25219
- SUG:NA
- DESC:fix CVE-2020-25219

* Tue May 25 2021 xinghe <xinghe2@huawei.com> - 0.4.15-17
- Type:bugfix
- CVE:NA
- SUG:NA
- DESC:delete mozjs-52 dependency 

* Mon Mar 29 2021 yuboyun <yuboyun@huawei.com> - 0.4.15-16
- Type:bugfix
- CVE:NA
- SUG:NA
- DESC:Fix mismatched new[]/delete[] in proxy.cpp

* Mon Nov 09 2020 gaihuiying <gaihuiying1@huawei.com> - 0.4.15-15
- Type:bugfix
- Id:NA
- SUG:NA
- DESC:drop dependency of libmodman

* Tue Oct 20 2020 hanzhijun <hanzhijun1@huawei.com> - 0.4.15-14
- Type:cves
- Id:NA
- SUG:NA
- DESC:fix CVE-2020-26154

* Sat Jan 11 2020 openEuler Buildteam <buildteam@openeuler.org> - 0.4.15-13
- Type:NA
- ID:NA
- SUG:NA
- DESC:fix patch source

* Thu Nov 28 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.4.15-12
- Type:bugfix
- Id:NA
- SUG:NA
- DESC:remove the webkitgtk4 package from main package

* Thu Oct 17 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.4.15-11
- Type:bugfix
- Id:NA
- SUG:NA
- DESC:remove the /usr/bin/kreadconfig5 in buildRequires.

* Tue Sep 10 2019 liyongqiang<liyongqiang10@huawei.com> - 0.4.15-10
- Package init
